@@ -4,13 +4,15 @@
 # of the KOLLA_BOOTSTRAP variable being set, including empty.
 if [[ "${!KOLLA_BOOTSTRAP[@]}" ]]; then
     heat-manage db_sync
-    CURRENT_HEAT_DOMAIN_NAME=$(openstack domain list | grep heat | awk '{print $4}')
 
-    if [[ "heat_user_domain" != "$CURRENT_HEAT_DOMAIN_NAME" ]]; then
+    EXISTING_DOMAINS=$(openstack domain list -f value -c Name)
+
+    if ! echo "$EXISTING_DOMAINS" | grep '^heat_user_domain$' &>/dev/null; then
         openstack domain create heat_user_domain
         openstack user create --domain heat_user_domain heat_domain_admin --password ${HEAT_DOMAIN_ADMIN_PASSWORD}
         openstack role add --domain heat_user_domain --user-domain heat_user_domain --user heat_domain_admin admin
     fi
+
     exit 0
 fi
 
