@@ -23,26 +23,21 @@ from kolla.version import version_info as version
 
 BASE_OS_DISTRO = ['centos', 'debian', 'rocky', 'ubuntu']
 BASE_ARCH = ['x86_64', 'aarch64']
+DEBIAN_ARCH = ['amd64', 'arm64']
 DEFAULT_BASE_TAGS = {
     'centos': {'name': 'quay.io/centos/centos', 'tag': 'stream9'},
-    'debian': {'name': 'debian', 'tag': 'bullseye'},
+    'debian': {'name': 'debian', 'tag': 'bookworm'},
     'rocky': {'name': 'quay.io/rockylinux/rockylinux', 'tag': '9'},
     'ubuntu': {'name': 'ubuntu', 'tag': '22.04'},
 }
 # NOTE(hrw): has to match PRETTY_NAME in /etc/os-release
 DISTRO_PRETTY_NAME = {
     'centos': 'CentOS Stream 9',
-    'debian': 'Debian GNU/Linux 11 (bullseye)',
+    'debian': 'Debian GNU/Linux 12 (bookworm)',
     'rocky': 'Rocky Linux 9.* (Blue Onyx)',
     'ubuntu': 'Ubuntu 22.04',
 }
-OPENSTACK_RELEASE = 'zed'
-
-# This is noarch repository so we will use it on all architectures
-DELOREAN_DEPS = "https://trunk.rdoproject.org/centos9-zed/" \
-    "delorean-deps.repo"
-
-INSTALL_TYPE_CHOICES = ['source']
+OPENSTACK_RELEASE = '2024.1'
 
 # TODO(mandre) check for file integrity instead of downloading from an HTTPS
 # source
@@ -66,7 +61,6 @@ _PROFILE_OPTS = [
                     'proxysql',
                     'rabbitmq',
                     'redis',
-                    'skydive',
                     'storm',
                     'tgtd',
                 ],
@@ -92,7 +86,6 @@ _PROFILE_OPTS = [
                     'blazar',
                     'cloudkitty',
                     'designate',
-                    'freezer',
                     'gnocchi',
                     'influxdb',
                     'ironic',
@@ -102,16 +95,11 @@ _PROFILE_OPTS = [
                     'manila',
                     'masakari',
                     'mistral',
-                    'murano',
                     'octavia',
                     'redis',
-                    'sahara',
-                    'senlin',
-                    'solum',
                     'tacker',
                     'telegraf',
                     'trove',
-                    'vitrage',
                     'zookeeper',
                     'zun',
                 ],
@@ -140,6 +128,14 @@ _PROFILE_OPTS = [
 ]
 
 hostarch = os.uname()[4]
+if hostarch == 'aarch64':
+    debianarch = 'arm64'
+elif hostarch == 'x86_64':
+    debianarch = 'amd64'
+
+# NOTE: Apple Silicon reports as arm64 which is aarch64
+if hostarch == "arm64":
+    hostarch = "aarch64"
 
 _CLI_OPTS = [
     cfg.StrOpt('base', short='b', default='rocky',
@@ -152,6 +148,10 @@ _CLI_OPTS = [
     cfg.StrOpt('base-arch', default=hostarch,
                choices=BASE_ARCH,
                help='The base architecture. Default is same as host.'),
+    cfg.StrOpt('debian-arch', default=debianarch,
+               choices=DEBIAN_ARCH,
+               help='The base architecture used for downloading external '
+               'packages. Default is derived from base-arch.'),
     cfg.BoolOpt('use-dumb-init', default=True,
                 help='Use dumb-init as init system in containers'),
     cfg.BoolOpt('debug', short='d', default=False,
@@ -159,7 +159,8 @@ _CLI_OPTS = [
     cfg.BoolOpt('skip-parents', default=False,
                 help='Do not rebuild parents of matched images'),
     cfg.BoolOpt('skip-existing', default=False,
-                help='Do not rebuild images present in the docker cache'),
+                help='Do not rebuild images present in the container engine '
+                'cache'),
     cfg.DictOpt('build-args',
                 help='Set docker build time variables'),
     cfg.BoolOpt('keep', default=False,
@@ -168,12 +169,18 @@ _CLI_OPTS = [
                 help='Show image dependencies (filtering supported)'),
     cfg.BoolOpt('list-images',
                 help='Show all available images (filtering supported)'),
+    cfg.StrOpt('locals-base', default='./',
+               help='Base directory for local source resolution'),
     cfg.StrOpt('namespace', short='n', default='kolla',
                help='The Docker namespace name'),
     cfg.StrOpt('network_mode', default='host',
                help='The network mode for Docker build. Example: host'),
     cfg.BoolOpt('cache', default=True,
-                help='Use the Docker cache when building'),
+                help='Use the container engine cache when building'),
+    cfg.StrOpt('platform', default=None,
+               help=('The platform to use for a cross-compile build. Should '
+                     'be set in conjunction with "--base-arch" argument. '
+                     'Example: "--platform linux/arm64 --base-arch aarch64"')),
     cfg.MultiOpt('profile', types.String(), short='p',
                  help=('Build a pre-defined set of images, see [profiles]'
                        ' section in config. The default profiles are:'
@@ -191,27 +198,26 @@ _CLI_OPTS = [
                  help=('Build only images matching regex and its'
                        ' dependencies')),
     cfg.StrOpt('registry',
-               help=('The docker registry host. The default registry host'
-                     ' is Docker Hub')),
+               help=('The container image registry host. The default registry'
+                     ' host is Docker Hub')),
     cfg.StrOpt('save-dependency',
                help=('Path to the file to store the docker image'
                      ' dependency in Graphviz dot format')),
     cfg.StrOpt('format', short='f', default='json',
                choices=['json', 'none'],
-               help='Format to write the final results in'),
+               help='Format to write the final results in.'),
+    cfg.StrOpt('summary-json-file',
+               help='Name of a file to write the build summary to when format '
+                    'is json. If unset, the summary will be written to '
+                    'standard output'),
     cfg.StrOpt('tarballs-base', default=TARBALLS_BASE,
                help='Base url to OpenStack tarballs'),
-    # NOTE(hrw): deprecate argument in Zed, remove in A-cycle
-    cfg.StrOpt('type', short='t', default='source',
-               choices=INSTALL_TYPE_CHOICES,
-               dest='install_type',
-               help=('Ignored, kept for script compatibility.')),
     cfg.IntOpt('threads', short='T', default=8, min=1,
                help=('The number of threads to use while building.'
                      ' (Note: setting to one will allow real time'
                      ' logging)')),
     cfg.StrOpt('tag', default=version.cached_version_string(),
-               help='The Docker tag'),
+               help='The container image tag'),
     cfg.BoolOpt('template-only', default=False,
                 help="Don't build images. Generate Dockerfile only"),
     cfg.IntOpt('timeout', default=120,
@@ -252,6 +258,10 @@ _CLI_OPTS = [
                help='Prefix prepended to image names'),
     cfg.StrOpt('repos-yaml', default='',
                help='Path to alternative repos.yaml file'),
+    cfg.StrOpt('engine', default='docker', choices=['docker', 'podman'],
+               help='Container engine to build images on.'),
+    cfg.StrOpt('podman_base_url', default='unix:///run/podman/podman.sock',
+               help='Path to podman socket.')
 ]
 
 _BASE_OPTS = [
@@ -267,7 +277,7 @@ _BASE_OPTS = [
                help=('Set the package type of the distro. If not set then '
                      'the packaging type is set to "rpm" if a RHEL based '
                      'distro and "deb" if a Debian based distro.')),
-    cfg.ListOpt('rpm_setup_config', default=[DELOREAN_DEPS],
+    cfg.ListOpt('rpm_setup_config', default=[],
                 help=('Comma separated list of .rpm or .repo file(s) '
                       'or URL(s) to install before building containers')),
     cfg.StrOpt('apt_sources_list', help=('Path to custom sources.list')),
@@ -283,7 +293,8 @@ _BASE_OPTS = [
 ]
 
 
-def get_source_opts(type_=None, location=None, reference=None, enabled=True):
+def get_source_opts(type_=None, location=None, reference=None, enabled=True,
+                    version=None, sha256=None):
     return [cfg.StrOpt('type', choices=['local', 'git', 'url'],
                        default=type_,
                        help='Source location type'),
@@ -293,7 +304,11 @@ def get_source_opts(type_=None, location=None, reference=None, enabled=True):
                        help=('Git reference to pull, commit sha, tag '
                              'or branch name')),
             cfg.BoolOpt('enabled', default=enabled,
-                        help=('Whether the source is enabled'))]
+                        help=('Whether the source is enabled')),
+            cfg.StrOpt('version', default=version,
+                       help=('Package version to download for GitHub '
+                             'sources')),
+            cfg.DictOpt('sha256', default=sha256)]
 
 
 def get_user_opts(uid, gid, group):
@@ -321,7 +336,10 @@ def gen_all_source_opts():
         location = params['location']
         reference = params.get('reference')
         enabled = params.get('enabled', True)
-        yield name, get_source_opts(type_, location, reference, enabled)
+        version = params.get('version')
+        sha256 = params.get('sha256')
+        yield name, get_source_opts(type_, location, reference, enabled,
+                                    version, sha256)
 
 
 def list_opts():
