@@ -168,7 +168,7 @@ class TasksTest(base.TestCase):
         mock_client().images.build.assert_called_once_with(
             path=self.image.path, tag=self.image.canonical_name,
             network_mode='host', nocache=False, rm=True, pull=True,
-            forcerm=True, buildargs=None, **self.build_kwargs)
+            forcerm=True, platform=None, buildargs=None, **self.build_kwargs)
 
         self.assertTrue(builder.success)
 
@@ -185,7 +185,7 @@ class TasksTest(base.TestCase):
         mock_client().images.build.assert_called_once_with(
             path=self.image.path, tag=self.image.canonical_name,
             network_mode='bridge', nocache=False, rm=True, pull=True,
-            forcerm=True, buildargs=None, **self.build_kwargs)
+            forcerm=True, platform=None, buildargs=None, **self.build_kwargs)
 
         self.assertTrue(builder.success)
 
@@ -205,7 +205,8 @@ class TasksTest(base.TestCase):
         mock_client().images.build.assert_called_once_with(
             path=self.image.path, tag=self.image.canonical_name,
             network_mode='host', nocache=False, rm=True, pull=True,
-            forcerm=True, buildargs=build_args, **self.build_kwargs)
+            forcerm=True, platform=None, buildargs=build_args,
+            **self.build_kwargs)
 
         self.assertTrue(builder.success)
 
@@ -224,7 +225,8 @@ class TasksTest(base.TestCase):
         mock_client().images.build.assert_called_once_with(
             path=self.image.path, tag=self.image.canonical_name,
             network_mode='host', nocache=False, rm=True, pull=True,
-            forcerm=True, buildargs=build_args, **self.build_kwargs)
+            forcerm=True, platform=None, buildargs=build_args,
+            **self.build_kwargs)
 
         self.assertTrue(builder.success)
 
@@ -245,7 +247,8 @@ class TasksTest(base.TestCase):
         mock_client().images.build.assert_called_once_with(
             path=self.image.path, tag=self.image.canonical_name,
             network_mode='host', nocache=False, rm=True, pull=True,
-            forcerm=True, buildargs=build_args, **self.build_kwargs)
+            forcerm=True, platform=None, buildargs=build_args,
+            **self.build_kwargs)
 
         self.assertTrue(builder.success)
 
@@ -293,6 +296,15 @@ class TasksTest(base.TestCase):
                        {'source': 'http://fake/source4', 'type': None,
                         'name': 'fake-image-base4',
                         'reference': 'http://fake/reference4',
+                        'enabled': True},
+                       {'source': 'http://fake/source${version}',
+                        'type': 'url',
+                        'name': 'fake-image-base5',
+                        'version': '5',
+                        'enabled': True},
+                       {'source': 'http://fake/source${debian_arch}',
+                        'type': 'url',
+                        'name': 'fake-image-base6',
                         'enabled': True}]:
             self.image.source = source
             push_queue = mock.Mock()
@@ -499,7 +511,8 @@ class KollaWorkerTest(base.TestCase):
             'reference': 'master',
             'source': 'https://opendev.org/x/networking-arista',
             'type': 'git',
-            'enabled': True
+            'enabled': True,
+            'sha256': None
         }
 
         found = False
@@ -742,6 +755,53 @@ class KollaWorkerTest(base.TestCase):
         self.assertEqual('error', results['failed'][0]['status'])  # bad
         self.assertEqual('error', results['failed'][1]['status'])  # bad2
 
+    @mock.patch('json.dump')
+    def test_summary_json_format(self, dump_mock):
+        self.conf.set_override('format', 'json')
+        kolla = build.KollaWorker(self.conf)
+        kolla.images = self.images
+        kolla.image_statuses_good['good'] = build.Status.BUILT
+        kolla.image_statuses_bad['bad'] = build.Status.ERROR
+        kolla.image_statuses_allowed_to_fail['bad2'] = build.Status.ERROR
+        kolla.image_statuses_unmatched['unmatched'] = build.Status.UNMATCHED
+        results = kolla.summary()
+        dump_mock.assert_called_once_with(results, sys.stdout)
+
+    @mock.patch('json.dump')
+    def test_summary_json_format_file(self, dump_mock):
+        tmpdir = tempfile.mkdtemp()
+        file_path = os.path.join(tmpdir, 'summary.json')
+        try:
+            self.conf.set_override('format', 'json')
+            self.conf.set_override('summary_json_file', file_path)
+            kolla = build.KollaWorker(self.conf)
+            kolla.images = self.images
+            kolla.image_statuses_good['good'] = build.Status.BUILT
+            kolla.image_statuses_bad['bad'] = build.Status.ERROR
+            kolla.image_statuses_allowed_to_fail['bad2'] = build.Status.ERROR
+            kolla.image_statuses_unmatched['unmatched'] = (
+                build.Status.UNMATCHED)
+            results = kolla.summary()
+            dump_mock.assert_called_once_with(results, mock.ANY, indent=4)
+            self.assertEqual(dump_mock.call_args[0][1].name, file_path)
+        finally:
+            os.remove(file_path)
+            os.rmdir(tmpdir)
+
+    @mock.patch('builtins.open')
+    def test_summary_json_format_file_error(self, open_mock):
+        open_mock.side_effect = OSError
+        self.conf.set_override('format', 'json')
+        self.conf.set_override('summary_json_file', 'fake-file')
+        kolla = build.KollaWorker(self.conf)
+        kolla.images = self.images
+        kolla.image_statuses_good['good'] = build.Status.BUILT
+        kolla.image_statuses_bad['bad'] = build.Status.ERROR
+        kolla.image_statuses_allowed_to_fail['bad2'] = build.Status.ERROR
+        kolla.image_statuses_unmatched['unmatched'] = (
+            build.Status.UNMATCHED)
+        self.assertRaises(SystemExit, kolla.summary)
+
     @mock.patch('shutil.copytree')
     def test_work_dir(self, copytree_mock):
         self.conf.set_override('work_dir', 'tmp/foo')
